Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
lice2/__init__.py | (no class) | 3 | 0 | 0 | 100%
lice2/api/__init__.py | (no class) | 2 | 0 | 0 | 100%
lice2/api/api.py | Lice | 33 | 0 | 0 | 100%
lice2/api/api.py | (no class) | 10 | 0 | 0 | 100%
lice2/api/exceptions.py | LiceError | 0 | 0 | 0 | 100%
lice2/api/exceptions.py | LicenseNotFoundError | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | LanguageNotFoundError | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | HeaderNotFoundError | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | InvalidYearError | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | (no class) | 10 | 0 | 0 | 100%
lice2/config.py | Settings | 0 | 0 | 0 | 100%
lice2/config.py | (no class) | 19 | 0 | 0 | 100%
lice2/constants.py | (no class) | 15 | 0 | 0 | 100%
lice2/core.py | (no class) | 46 | 0 | 1 | 100%
lice2/helpers.py | (no class) | 184 | 0 | 0 | 100%
lice2/templates/__init__.py | (no class) | 0 | 0 | 0 | 100%
Total |  | 330 | 0 | 1 | 100%

No items found using the specified filter.